#
# spec file for package python-oletools
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-oletools
Version:        0.60
Release:        3.5
Summary:        Tools to analyze security characteristics of MS Office and OLE files
License:        BSD-2-Clause AND MIT
URL:            http://www.decalage.info/python/oletools
Source:         https://files.pythonhosted.org/packages/source/o/oletools/oletools-%{version}.zip
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module colorclass}
BuildRequires:  %{python_module easygui}
BuildRequires:  %{python_module msoffcrypto-tool}
BuildRequires:  %{python_module olefile >= 0.46}
BuildRequires:  %{python_module pyparsing >= 2.1.0}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  unzip
BuildRequires:  fdupes
%if 0%{?sle_version} == 150200 || 0%{?sle_version} == 150300
BuildRequires:  python2-xml
%endif
Requires:       python-colorclass
Requires:       python-easygui
Requires:       python-msoffcrypto-tool
Requires:       python-olefile >= 0.46
Recommends:     python-pcodedmp >= 1.2.5
Requires:       python-pyparsing >= 2.1.0
%if "%{python_flavor}" == "python2"
Requires:       python2-xml
%endif
BuildArch:      noarch
%python_subpackages

%description
Python tools to analyze security characteristics of MS Office and OLE files (also called Structured Storage, Compound File Binary Format or Compound Document File Format), for Malware Analysis and Incident Response (DFIR)

%prep
%setup -q -n oletools-%{version}
find oletools -name "*.py" -exec sed -i '1{/\/bin\/env python/d;}' {} \+
find oletools -name "*.py" -exec sed -i 's/\r\n/\n/' {} \+

%build
%python_build

%install
%python_install
# remove actually optional dependency from requires
sed -i '1{/pcodedmp/d;}' %{buildroot}%{python_sitelib}/oletools-*.egg-info/requires.txt
%python_clone -a %{buildroot}%{_bindir}/ezhexviewer
%python_clone -a %{buildroot}%{_bindir}/mraptor
%python_clone -a %{buildroot}%{_bindir}/olebrowse
%python_clone -a %{buildroot}%{_bindir}/oledir
%python_clone -a %{buildroot}%{_bindir}/oleid
%python_clone -a %{buildroot}%{_bindir}/olemap
%python_clone -a %{buildroot}%{_bindir}/olemeta
%python_clone -a %{buildroot}%{_bindir}/oletimes
%python_clone -a %{buildroot}%{_bindir}/olevba
%python_clone -a %{buildroot}%{_bindir}/pyxswf
%python_clone -a %{buildroot}%{_bindir}/rtfobj
%python_clone -a %{buildroot}%{_bindir}/oleobj
%python_clone -a %{buildroot}%{_bindir}/msodde
%python_clone -a %{buildroot}%{_bindir}/olefile
%python_clone -a %{buildroot}%{_bindir}/ftguess
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not test_rough_doctype and not test_encrypted and not test_crypt_return and not test_all'

%post
%python_install_alternative ezhexviewer mraptor olebrowse oledir oleid olemap olemeta oletimes olevba pyxswf rtfobj oleobj msodde olefile ftguess

%postun
%python_uninstall_alternative ezhexviewer

%files %{python_files}
%doc README.md
%license oletools/LICENSE.txt
%python_alternative %{_bindir}/ezhexviewer
%python_alternative %{_bindir}/mraptor
%python_alternative %{_bindir}/olebrowse
%python_alternative %{_bindir}/oledir
%python_alternative %{_bindir}/oleid
%python_alternative %{_bindir}/olemap
%python_alternative %{_bindir}/olemeta
%python_alternative %{_bindir}/oletimes
%python_alternative %{_bindir}/olevba
%python_alternative %{_bindir}/pyxswf
%python_alternative %{_bindir}/rtfobj
%python_alternative %{_bindir}/oleobj
%python_alternative %{_bindir}/msodde
%python_alternative %{_bindir}/olefile
%python_alternative %{_bindir}/ftguess
%{python_sitelib}/*

%changelog
* Tue Dec 14 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Sun Jul  4 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Fix package builds for Leap 15.2 and 15.3, python-xml dependency was missing.
* Mon Jun 21 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.60:
  - ftguess: new tool to identify file formats and containers (issue #680)
  - oleid: (issue #679)
  - each indicator now has a risk level
  - calls ftguess to identify file formats
  - calls olevba+mraptor to detect and analyse VBA+XLM macros
  - olevba:
  - when XLMMacroDeobfuscator is available, use it to extract and deobfuscate XLM macros
  - rtfobj:
  - use ftguess to identify file type of OLE Package (issue #682)
  - fixed bug in re_executable_extensions
  - crypto: added PowerPoint transparent password '/01Hannes Ruescher/01' (issue #627)
  - setup: XLMMacroDeobfuscator, xlrd2 and pyxlsb2 added as optional dependencies
* Sun May  9 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.56.2:
  - olevba:
  - updated plugin_biff to v0.0.22 to fix a bug (issues #647, #674)
  - olevba, mraptor:
  - added detection of Workbook_BeforeClose (issue #518)
  - rtfobj:
  - fixed bug when OLE package class name ends with null characters (issue #507, PR #648)
  - oleid:
  - fixed bug in check_excel (issue #584, PR #585)
  - clsid:
  - added several CLSIDs related to MS Office click-to-run issue CVE-2021-27058
  - added checks to ensure that all CLSIDs are uppercase (PR #678)
* Mon Apr  5 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.56.1:
  - olevba:
  - fixed bug when parsing some malformed files (issue #629)
  - oleobj:
  - fixed bug preventing detection of links 'externalReference', 'frame', 'hyperlink' (issue #641, PR #670)
  - setup:
  - avoid installing msoffcrypto-tool when platform is PyPy+Windows (issue #473)
  - PyPI version is now a wheel package to improve installation and avoid antivirus false positives due to test files (issues #215, #398)
* Sat Jan 23 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 0.56
